==> jaxws-rt-2.2.6-2-sources.jar: com/sun/xml/ws/api/databinding/MappingInfo.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2011 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package com.sun.xml.ws.api.databinding;

import javax.xml.namespace.QName;

import com.sun.xml.ws.api.BindingID;

/**
 * A MappingInfo object is the collection of all the properties of the mapping
 * between a JAVA contract class (SEI) and it's corresponding WSDL artifacts
 * (wsdl:portType and wsdl:binding). A MappingInfo object can be used to provide
 * additional mapping metadata for WSDL generation and the runtime of WebService
 * databinding.
 * 
 * @author shih-chang.chen@oracle.com
 */
public class MappingInfo {
	protected String targetNamespace;
	protected String databindingMode;
	protected SoapBodyStyle soapBodyStyle;
	protected BindingID bindingID;
	protected QName serviceName;
	protected QName portName;
	
	public String getTargetNamespace() {
		return targetNamespace;
	}
	public void setTargetNamespace(String targetNamespace) {
		this.targetNamespace = targetNamespace;
	}
	public String getDatabindingMode() {
		return databindingMode;
	}
	public void setDatabindingMode(String databindingMode) {
		this.databindingMode = databindingMode;
	}
	public SoapBodyStyle getSoapBodyStyle() {
		return soapBodyStyle;
	}
	public void setSoapBodyStyle(SoapBodyStyle soapBodyStyle) {
		this.soapBodyStyle = soapBodyStyle;
	}
	public BindingID getBindingID() {
		return bindingID;
	}
	public void setBindingID(BindingID bindingID) {
		this.bindingID = bindingID;
	}
	public QName getServiceName() {
		return serviceName;
	}
	public void setServiceName(QName serviceName) {
		this.serviceName = serviceName;
	}
	public QName getPortName() {
		return portName;
	}
	public void setPortName(QName portName) {
		this.portName = portName;
	}
}

==> jaxws-rt-2.2.7-sources.jar: com/sun/xml/ws/api/databinding/MappingInfo.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2012 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package com.sun.xml.ws.api.databinding;

import javax.xml.namespace.QName;

import com.sun.xml.ws.api.BindingID;

/**
 * A MappingInfo object is the collection of all the properties of the mapping
 * between a JAVA contract class (SEI) and it's corresponding WSDL artifacts
 * (wsdl:portType and wsdl:binding). A MappingInfo object can be used to provide
 * additional mapping metadata for WSDL generation and the runtime of WebService
 * databinding.
 * 
 * @author shih-chang.chen@oracle.com
 */
public class MappingInfo {
	protected String targetNamespace;
	protected String databindingMode;
	protected SoapBodyStyle soapBodyStyle;
	protected BindingID bindingID;
	protected QName serviceName;
	protected QName portName;
	protected String defaultSchemaNamespaceSuffix;
	
    public String getTargetNamespace() {
		return targetNamespace;
	}
	public void setTargetNamespace(String targetNamespace) {
		this.targetNamespace = targetNamespace;
	}
	public String getDatabindingMode() {
		return databindingMode;
	}
	public void setDatabindingMode(String databindingMode) {
		this.databindingMode = databindingMode;
	}
	public SoapBodyStyle getSoapBodyStyle() {
		return soapBodyStyle;
	}
	public void setSoapBodyStyle(SoapBodyStyle soapBodyStyle) {
		this.soapBodyStyle = soapBodyStyle;
	}
	public BindingID getBindingID() {
		return bindingID;
	}
	public void setBindingID(BindingID bindingID) {
		this.bindingID = bindingID;
	}
	public QName getServiceName() {
		return serviceName;
	}
	public void setServiceName(QName serviceName) {
		this.serviceName = serviceName;
	}
	public QName getPortName() {
		return portName;
	}
	public void setPortName(QName portName) {
		this.portName = portName;
	}    
    public String getDefaultSchemaNamespaceSuffix() {
        return defaultSchemaNamespaceSuffix;
    }
    public void setDefaultSchemaNamespaceSuffix(String defaultSchemaNamespaceSuffix) {
        this.defaultSchemaNamespaceSuffix = defaultSchemaNamespaceSuffix;
    }
}
